==> s-1.0.1.tgz: package/src/utils/aws/createOrUpdateLambda.js <==
const AWS = require('aws-sdk')

const createLambda = async ({name, description, memory, timeout, env, lambdaRoleArn, pkg, region}) => {
  const lambda = new AWS.Lambda({region})
  const params = {
    FunctionName: name,
    Code: {
      ZipFile: pkg
    },
    Description: description,
    Handler: 'handler.s',
    MemorySize: memory,
    Publish: true,
    Role: lambdaRoleArn,
    Runtime: 'nodejs8.10',
    Timeout: timeout,
    Environment: {
      Variables: env
    }
  }

  const res = await lambda.createFunction(params).promise()
  return res.FunctionArn
}

const updateLambda = async ({name, description, memory, timeout, env, lambdaRoleArn, pkg, region}) => {
  const lambda = new AWS.Lambda({region})
  const functionCodeParams = {
    FunctionName: name,
    ZipFile: pkg,
    Publish: true
  }

  const functionConfigParams = {
    FunctionName: name,
    Description: description,
    Handler: 'handler.s',
    MemorySize: memory,
    Role: lambdaRoleArn,
    Runtime: 'nodejs8.10',
    Timeout: timeout,
    Environment: {
      Variables: env
    }
  }

  await lambda.updateFunctionConfiguration(functionConfigParams).promise()
  const res = await lambda.updateFunctionCode(functionCodeParams).promise()
  return res.FunctionArn
}

module.exports = async (config) => {
  let lambdaArn

  try {
    lambdaArn = await createLambda(config)
  } catch (e) {
    if (e.message.includes('Function already exist')) {
      lambdaArn = await updateLambda(config)
    } else {
      throw new Error(e)
    }
  }
  return lambdaArn
}

==> s-1.0.3.tgz: package/src/utils/aws/createOrUpdateLambda.js <==
const AWS = require('aws-sdk')

const lambdaExists = async ({name, region}) => {
  const lambda = new AWS.Lambda({region})
  let exists = true
  try {
    await lambda.getFunction({ FunctionName: name }).promise()
  } catch (e) {
    if (e.message.includes('Function not found')) {
      exists = true
    } else {
      throw e
    }
  }
  return exists
}

const createLambda = async ({name, description, memory, timeout, env, lambdaRoleArn, pkg, region}) => {
  const lambda = new AWS.Lambda({region})
  const params = {
    FunctionName: name,
    Code: {
      ZipFile: pkg
    },
    Description: description,
    Handler: 'handler.s',
    MemorySize: memory,
    Publish: true,
    Role: lambdaRoleArn,
    Runtime: 'nodejs8.10',
    Timeout: timeout,
    Environment: {
      Variables: env
    }
  }

  const res = await lambda.createFunction(params).promise()
  return res.FunctionArn
}

const updateLambda = async ({name, description, memory, timeout, env, lambdaRoleArn, pkg, region}) => {
  const lambda = new AWS.Lambda({region})
  const functionCodeParams = {
    FunctionName: name,
    ZipFile: pkg,
    Publish: true
  }

  const functionConfigParams = {
    FunctionName: name,
    Description: description,
    Handler: 'handler.s',
    MemorySize: memory,
    Role: lambdaRoleArn,
    Runtime: 'nodejs8.10',
    Timeout: timeout,
    Environment: {
      Variables: env
    }
  }

  await lambda.updateFunctionConfiguration(functionConfigParams).promise()
  const res = await lambda.updateFunctionCode(functionCodeParams).promise()
  return res.FunctionArn
}

module.exports = async (config) => await lambdaExists(config) ? updateLambda(config) : createLambda(config)
